@@ -3,7 +3,7 @@ use warnings;
 
 package HTTP::Async;
 
-our $VERSION = '0.25';
+our $VERSION = '0.27';
 
 use Carp;
 use Data::Dumper;
@@ -782,6 +782,12 @@ sub _send_request {
     $args{LocalAddr} = $self->_get_opt('local_addr', $id );
     $args{LocalPort} = $self->_get_opt('local_port', $id );
 
+    # https://rt.cpan.org/Public/Bug/Display.html?id=33071
+    $args{Timeout} = $self->_get_opt( 'timeout', $id);
+
+    # ACF - Pass ssl_options through
+    $args{ssl_opts} = $self->_get_opt( 'ssl_options', $id);
+
     my $request_is_to_proxy =
       ( $args{PeerAddr} || $args{PeerPort} )    # if either are set...
       ? 1                                       # ...then we are a proxy request
@@ -945,6 +951,10 @@ rt.cpan.org user 'Florian (fschlich)' for typo in documentation.
 
 Heikki Vatiainen for the ssl_options support patch.
 
+Daniel Lintott of the Debian Perl Group for pointing out a test failure when
+using a very recent version of HTTP::Server::Simple to implement
+t/TestServer.pm
+
 =head1 BUGS AND REPO
 
 Please submit all bugs, patches etc on github
